@@ -2,7 +2,19 @@ import numpy as np
 from librosa.segment import recurrence_matrix
 from librosa.util import localmax
 from scipy.ndimage import convolve
-from ..data.metadata import Metadata
+from ..data.regions import Regions
+
+__all__ = [
+    'from_recurrence_matrix'
+]
+
+
+def checker(N):
+    block = np.zeros((N * 2 + 1, N * 2 + 1), dtype=np.int32)
+    for k in range(-N, N + 1):
+        for l in range(-N, N + 1):
+            block[k + N, l + N] = np.sign(k) * np.sign(l)
+    return block / abs(block).sum()
 
 
 def from_recurrence_matrix(X,
@@ -12,12 +24,6 @@ def from_recurrence_matrix(X,
                            bandwidth=1.,
                            thresh=0.2,
                            min_dur=4):
-    def checker(N):
-        block = np.zeros((N * 2 + 1, N * 2 + 1), dtype=np.int32)
-        for k in range(-N, N + 1):
-            for l in range(-N, N + 1):
-                block[k + N, l + N] = np.sign(k) * np.sign(l)
-        return block / abs(block).sum()
 
     R = recurrence_matrix(
         X, metric="cosine", mode="affinity",
@@ -32,4 +38,4 @@ def from_recurrence_matrix(X,
     mx = mx * (np.diff(mx, append=R.shape[0]) >= min_dur)
     mx = mx[mx > 0]
     stops = np.r_[mx, R.shape[0]]
-    return Metadata.from_stop(stops)
\ No newline at end of file
+    return Regions.from_stop(stops)
