@@ -1,7 +1,7 @@
 from .freqnet import *
 from .parametrized_gaussian import *
 from .sample_rnn import *
-from .seq2seq_lstms import *
+from .s2s_lstm import *
 from .tied_autoencoder import *
 from .transformers import *
 from .wavenet import *
